@@ -369,54 +369,21 @@ ask_user_a_file (char *path, char *prompt,
 	}
 }
 
-
-int
-runProg (char *cmd)
-{
-	int status;
-	pid_t pid;
-
-	char *c, *argv[5];
-	int argc = 0;
-	while (cmd && (*cmd != (char) NULL))
-	{
-		if ((c = strchr (cmd, ' ')) != NULL)
-			*c++ = (char) NULL;
-		argv[argc++] = cmd;
-		cmd = c;
-	}
-	argv[argc++] = NULL;
-
-	if ((pid = fork ()) < 0)
-	{
-		perror ("fork");
-		return (1);
-	}
-	if (pid == 0)
-	{
-		execvp (*argv, argv);
-		perror (*argv);
-		return (2);
-	}
-	while (wait (&status) != pid) /* do nothing */ ;
-
-	return status;
-}
-
-int
+gint
 system_and_gfree (gchar * cmd)
 {
-	int rv;
-	gchar *buf;
-	rv = runProg (cmd);
-	if (rv != 0)
-	{
-		buf = g_strdup_printf
-			("%s\n failed with return code %d\nperhaps you have \nmisinstalled something",
-			 cmd, rv);
-		gpe_error_box (buf);
-		g_free (buf);
-	}
+	gint rv = 0;
+		
+	if ((!g_spawn_command_line_sync (cmd, NULL, NULL, &rv, NULL))
+	    && (rv != 0))
+	    	{
+			gchar *buf;
+			buf = g_strdup_printf ("%s\n failed with return code %d\n " \
+			                       "perhaps you have \nmisinstalled something",
+				                   cmd, rv);
+			gpe_error_box (buf);
+			g_free (buf);
+		}
 	g_free (cmd);
 	return rv;
 }
